Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(683)

Unified Diff: remoting/host/cast_extension_session.h

Issue 810133003: replace NULL->nullptr in src/remoting. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/audio_scheduler.cc ('k') | remoting/host/cast_extension_session.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/cast_extension_session.h
diff --git a/remoting/host/cast_extension_session.h b/remoting/host/cast_extension_session.h
index 3b3ee72195862d94ab519582ff532fe3bdb0fcdd..48d97a438706eaed8bb15c7c4410607af2ccfcb8 100644
--- a/remoting/host/cast_extension_session.h
+++ b/remoting/host/cast_extension_session.h
@@ -155,9 +155,9 @@ class CastExtensionSession : public HostExtensionSession,
// Creates the jingle wrapper for the current thread, sets send to allowed,
// and saves a pointer to the relevant thread pointer in ptr. If |event|
// is not NULL, signals the event on completion.
void EnsureTaskAndSetSend(rtc::Thread** ptr,
- base::WaitableEvent* event = NULL);
+ base::WaitableEvent* event = nullptr);
// Wraps each task runner in JingleThreadWrapper using EnsureTaskAndSetSend(),
// returning true if successful. Wrapping the task runners allows them to be
« no previous file with comments | « remoting/host/audio_scheduler.cc ('k') | remoting/host/cast_extension_session.cc » ('j') | no next file with comments »
@@ -155,9 +155,9 @@ class CastExtensionSession : public HostExtensionSession,
// Creates the jingle wrapper for the current thread, sets send to allowed,
// and saves a pointer to the relevant thread pointer in ptr. If |event|
- // is not NULL, signals the event on completion.
+ // is not nullptr, signals the event on completion.
void EnsureTaskAndSetSend(rtc::Thread** ptr,

Powered by Google App Engine
This is Rietveld 408576698